****************
triangular grids
****************

:mod:`matplotlib.tri`
=====================
.. automodule:: matplotlib.tri

.. autoclass:: matplotlib.tri.Triangulation
    :members:

.. autoclass:: matplotlib.tri.TriFinder

.. autoclass:: matplotlib.tri.TrapezoidMapTriFinder
    :members: __call__
    :show-inheritance:

.. autoclass:: matplotlib.tri.TriInterpolator
   
.. autoclass:: matplotlib.tri.LinearTriInterpolator
    :members: __call__, gradient
    :show-inheritance:

.. autoclass:: matplotlib.tri.CubicTriInterpolator
    :members: __call__, gradient
    :show-inheritance:

.. autoclass:: matplotlib.tri.TriRefiner

.. autoclass:: matplotlib.tri.UniformTriRefiner
    :show-inheritance:
    :members: 

.. autoclass:: matplotlib.tri.TriAnalyzer
    :members: 
